ExportStatusLog

Struct ExportStatusLog 

pub struct ExportStatusLog {
    pub export_date: String,
    pub status: i32,
    pub event_count: i64,
    pub message: String,
}
ExportStatusLog is used in a log entry to represent the status of a given BigQuery export job from Google Analytics. Typically, it is sent at the beginning of the day to indicate the completion of the previous day’s export.

Fields

export_date: String

The date of the export. Usually set to the collection date (YYYYMMDD).

status: i32

The status of the export.

event_count: i64

The number of events exported, may include events not eligible for SLA.

message: String

Additional information associated with the status.

Implementations

Source

impl ExportStatusLog

pub fn status(&self) -> Status

Returns the enum value of status, or the default if the field is set to an invalid enum value.

pub fn set_status(&mut self, value: Status)

Sets status to the provided enum value.