pub struct ExportStatusLog {
pub export_date: String,
pub status: i32,
pub event_count: i64,
pub message: String,
}Expand description
ExportStatusLog is used in a log entry to represent the status of a given BigQuery export job from Google Analytics. Typically, it is sent at the beginning of the day to indicate the completion of the previous day’s export.
Fields
export_date: StringThe date of the export. Usually set to the collection date (YYYYMMDD).
status: i32The status of the export.
event_count: i64The number of events exported, may include events not eligible for SLA.
message: StringAdditional information associated with the status.
Implementations